import {
  select,
  geoPath,
  geoCentroid,
  geoNaturalEarth1,
  zoom,
  event,
  scaleOrdinal,
  schemeSpectral,
  scaleSqrt,
  max
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);
const radiusScale = scaleSqrt();
const radiusValue = d => d.properties['2018'];

const g = svg.append('g');

const colorLegendG = svg.append('g')
    .attr('transform', `translate(40,310)`);

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));

const colorScale = scaleOrdinal();

// const colorValue = d => d.properties.income_grp;
const colorValue = d => d.properties.economy;

loadAndProcessData().then(countries => {
  
  radiusScale
    .domain([0, max(countries.features, radiusValue)])
  	.range([0, 20]);
  
  g.selectAll('path').data(countries.features)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
      .attr('fill', d => d.properties['2018'] ? '#e8e8e8':'#fecccc')
    .append('title')
      .text(d => d.properties.name + ': ' + colorValue(d));
  
  //radiusValue(countries.features[0]);
  
  countries.featuresWithPopulation.forEach(d =>{
  	d.properties.projection = projection(geoCentroid(d));  
  });
  
  g.selectAll('circle').data(countries.featuresWithPopulation)
    .enter().append('circle')
      .attr('class', 'country-circle')
  		.attr('cx', d => d.properties.projection[0])
  		.attr('cy', d => d.properties.projection[1])
  		.attr('r', d => radiusScale(radiusValue(d)));
});